require File.expand_path(File.dirname(__FILE__) + '/spec_helper')

describe "SmtpcomApi::Request" do
  let(:client){ mock("Client").extend(SmtpcomApi::Request)  }

  it "could get" do
    client.respond_to? :get
  end

  it "could put" do
    client.respond_to? :put
  end

  it "could post" do
    client.respond_to? :post
  end

  it "could delete" do
    client.respond_to? :delete
  end

  it "should convert time closures to int" do
    time = Time.now
    client.send(:process_params, {:time_start => time})[:time_start].should == time.to_i
    client.send(:process_params, {:time_end   => time})[:time_end].should == time.to_i
  end

  it "should make call when get/post/put/delete" do
    SmtpcomApi::Request::Urls::SOMEKEY = "/test"
    client.stub(:_call).and_return(1)
    
    client.get(:somekey).should     == 1
    client.put(:somekey).should     == 1
    client.post(:somekey).should    == 1
    client.delete(:somekey).should  == 1
  end

  it "should make correct path" do
    SmtpcomApi::Request::Urls::SOMEPATH = "/account/senders/%s/statistics/campaigns/%s"
    path = client.send(:get_path, :somepath, ['label', 'campaign_id'])
    path.should == "/account/senders/label/statistics/campaigns/campaign_id"
  end

  it "should make correct path 2" do
    SmtpcomApi::Request::Urls::SOMEPATH2 = "/account/senders/%s/statistics/delivery"
    path = client.send(:get_path, :somepath2, 'label')
    path.should == "/account/senders/label/statistics/delivery"
  end

  it "should combine correct url" do
    host = 'http://myapi.com'
    path = '/account/senders/label/statistics/delivery'
    api_path = '/v1'
    format = 'json'
    client.instance_variable_set(:@api_host, host)
    client.stub(:get_path).and_return(path)
    client.send(:get_url, :somekey).should == [host,api_path,path,".#{format}"].join
  end

end
