require File.expand_path(File.dirname(__FILE__) + '/spec_helper')

describe "SmtpcomApi::Sender" do
  describe "sender" do

    use_vcr_cassette 'client'
    let(:sender) { SmtpcomApi::Sender.new('vasiliy', API_KEY, API_HOST) }

    describe "like a client" do
      let(:client) { sender }
      it_behaves_like "a client"
    end

    describe "attributes" do
      subject { sender }

      it { should respond_to :label }
      it { should respond_to :login }
      it { should respond_to :id }
    end

    describe "statistics" do 
      subject { sender }    
      [:summary, :delivery, :campaigns, :complaints, :queue, :campaign].each do |key|
        it {sender.should respond_to key }
      end

    end

    it "should be able to reload attributes" do
      sender.reload.should be_an_instance_of(SmtpcomApi::Sender)
    end

    it "should be able to save attributes" do
      sender.save.should be_an_instance_of(SmtpcomApi::Sender)
    end
  end

  describe "allowed ips" do
    use_vcr_cassette 'client'
    before(:all) { 
      VCR.use_cassette 'client' do
        @ipauth = SmtpcomApi::Sender.new('ipauth', API_KEY, API_HOST) 
      end
    }
    it "should add allowed ip" do
      @ipauth.add_allowed_ip('233.221.1.2')
      @ipauth.allowed_ips.map{|aip| aip['range']}.should include '233.221.1.2'
    end

    it "should remove allowed ip" do
      @ipauth.remove_allowed_ip('233.221.1.2')
      @ipauth.allowed_ips.map{|aip| aip['range']}.should_not include '233.221.1.2'
    end
  end

end
